@@ -39,36 +39,34 @@ def join_fasta(
 
     For more advanced functions, please use phylopandas.
 
-    Functional usage example:
-
-    ```python
-    import pandas as pd
-    import janitor.biology
-
-    df = pd.DataFrame(...)
-
-    df = janitor.biology.join_fasta(
-        df=df,
-        filename='fasta_file.fasta',
-        id_col='sequence_accession',
-        column_name='sequence',
-    )
-    ```
-
     Method chaining usage example:
 
-    ```python
-    import pandas as pd
-    import janitor.biology
+    >>> import tempfile
+    >>> import pandas as pd
+    >>> import janitor.biology
 
-    df = pd.DataFrame(...)
+    >>> tf = tempfile.NamedTemporaryFile()
+    >>> tf.write('''>SEQUENCE_1
+    ... MTEITAAMVKELRESTGAGMMDCK
+    ... >SEQUENCE_2
+    ... SATVSEINSETDFVAKN'''.encode('utf8'))
+    66
+    >>> tf.seek(0)
+    0
 
-    df = df.join_fasta(
-        filename='fasta_file.fasta',
-        id_col='sequence_accession',
-        column_name='sequence',
-    )
-    ```
+    >>> df = pd.DataFrame({"sequence_accession":
+    ... ["SEQUENCE_1", "SEQUENCE_2", ]})
+
+    >>> df = df.join_fasta(
+    ...     filename=tf.name,
+    ...     id_col='sequence_accession',
+    ...     column_name='sequence',
+    ... )
+
+    >>> df.sequence
+    0    MTEITAAMVKELRESTGAGMMDCK
+    1           SATVSEINSETDFVAKN
+    Name: sequence, dtype: object
 
     :param df: A pandas DataFrame.
     :param filename: Path to the FASTA file.
